@@ -12,7 +12,7 @@ use platform_dirs::AppDirs;
 use crate::command::{SortDirection, SortKey};
 use crate::model::playable::Playable;
 use crate::queue;
-use crate::serialization::{Serializer, CBOR, TOML};
+use crate::serialization::{CBOR, Serializer, TOML};
 
 pub const CACHE_VERSION: u16 = 1;
 pub const DEFAULT_COMMAND_KEY: char = ':';
@@ -257,7 +257,7 @@ impl Config {
         let path = config_path(USER_STATE_FILE_NAME);
         debug!("saving user state to {}", path.display());
         if let Err(e) = CBOR.write(path, &*self.state()) {
-            error!("Could not save user state: {}", e);
+            error!("Could not save user state: {e}");
         }
     }
 
