@@ -6,8 +6,8 @@ use std::error::Error;
 use std::sync::Arc;
 use std::time::Duration;
 use tokio::sync::mpsc;
-use tokio_stream::wrappers::UnboundedReceiverStream;
 use tokio_stream::StreamExt;
+use tokio_stream::wrappers::UnboundedReceiverStream;
 use zbus::object_server::SignalEmitter;
 use zbus::zvariant::{ObjectPath, Value};
 use zbus::{connection, interface};
@@ -274,10 +274,10 @@ impl MprisPlayer {
     }
 
     #[zbus(property)]
-    fn set_volume(&self, mut volume: f64) {
+    fn set_volume(&self, volume: f64) {
         log::info!("set volume: {volume}");
-        volume = volume.clamp(0.0, 1.0);
-        let vol = (VOLUME_PERCENT as f64) * volume * 100.0;
+        let clamped = volume.clamp(0.0, 1.0);
+        let vol = (VOLUME_PERCENT as f64) * clamped * 100.0;
         self.spotify.set_volume(vol as u16, false);
         self.event.trigger();
     }
